@@ -1,6 +1,6 @@
 package Facebook::Graph::Response;
 BEGIN {
-  $Facebook::Graph::Response::VERSION = '1.0401';
+  $Facebook::Graph::Response::VERSION = '1.0500';
 }
 
 use Any::Moose;
@@ -8,7 +8,8 @@ use JSON;
 use Ouch;
 
 has response => (
-    is      => 'ro',
+    is      => 'rw',
+    isa     => 'HTTP::Response',
     required=> 1,
 );
 
@@ -59,12 +60,11 @@ Facebook::Graph::Response - Handling of a Facebook::Graph response documents.
 
 =head1 VERSION
 
-version 1.0401
+version 1.0500
 
 =head1 DESCRIPTION
 
-You'll be given one of these as a result of calling the C<request> method on a C<Facebook::Graph::Query> or others.
-
+You'll be given one of these as a result of calling the C<request> method on a L<Facebook::Graph::Query> or others, or C<publish> on any of the L<Facebook::Graph::Publish> modules.
 
 =head1 METHODS
 
